"""Convert between Chinese Telegraph Codes and Unicode Chinese characters.

See <https://en.wikipedia.org/wiki/Chinese_telegraph_code> for details about
Chinese Telegraph Codes.

The codebooks are derived from the Unicode consortium's Unihan database:
<https://www.unicode.org/Public/UNIDATA/Unihan.zip>.
"""

__version__ = "0.1.0"
__author__ = "Charles Simpson"

# TODO use dict lookups instead of searching through the codebook string

from io import TextIOWrapper
from zipfile import ZipFile


def to_telecode(unicode, encoding=None):
    """Encode unicode string to telecode.

    >>> to_telecode("中文信息")
    ['0022', '2429', '0207', '1873']

    Because of differences between simplified and traditional characters, two
    different unicode strings may encode to the same telecode:
    >>> to_telecode("萧爱国")
    ['5618', '1947', '0948']

    >>> to_telecode("蕭愛國")
    ['5618', '1947', '0948']

    There are 419 characters where the mainland Taiwanese codebooks have
    diverged: the same character maps to two different codes depending on the
    codebook. For example, "仉" (U+4EC9) maps to '8022' in the mainland
    codebook, but '0097' in the Taiwan codebook. In these cases, `encoding`
    must be specified as 'mainland' or 'taiwan' to disambiguate. Failure to
    specify an encoding will result in a LookupError.
    >>> to_telecode("仉")
    Traceback (most recent call last):
     ...
    LookupError: ambiguous encoding for "仉" (U+4EC9)

    >>> to_telecode("仉", encoding="mainland")
    ['8022']

    >>> to_telecode("仉", encoding="taiwan")
    ['0097']

    `encoding` may also be given to explicitly choose a codebook, even when
    there is no ambiguity. Failure to find the character in the chosen codebook
    will result in a LookupError.
    >>> to_telecode("萧爱国", encoding="mainland")
    ['5618', '1947', '0948']

    >>> to_telecode("蕭愛國", encoding="mainland")
    Traceback (most recent call last):
     ...
    LookupError: undefined encoding for "蕭" (U+856D)

    There are two cases: '塵' (U+5875) and '萼' (U+843C) where the database
    gives two different Taiwan telegraph codes (there are no such cases for
    mainland).

    In the case of '塵', there is no corresponding mainland code;
    only two Taiwan codes ('1057' and '7775'). The mainland code '1057' instead
    corresponds to '尘' (U+5C18) and '7775' corresponds to '铈' (U+94C8).
    Somewhat arbitrarily use '1057'.
    >>> to_telecode("塵", encoding="taiwan")
    ['1057']

    In the case of '萼', mainland and one of the Taiwan codes is '5501', but
    Taiwan also has a secondary code '9795'. Since both encodings accept
    '5501', choose it when encoding '萼'.
    >>> to_telecode("萼", encoding="taiwan")
    ['5501']
    """
    if not encoding:
        codes = __to_telecode_combined(unicode)
    elif encoding.lower() == "mainland":
        codes = __to_telecode_single(unicode, _MAINLAND_CODEBOOK)
    elif encoding.lower() == "taiwan":
        codes = __to_telecode_single(unicode, _TAIWAN_CODEBOOK)
    else:
        raise NotImplementedError('undefined encoding type "encoding"')

    return [str(c).zfill(4) for c in codes]


def __to_telecode_single(unicode, codebook):
    """Encode unicode to telecode using either mainland or Taiwan codebooks.
    """
    codes = []
    for char in unicode:
        try:
            codes.append(codebook.index(char))
        except ValueError as err:
            raise LookupError(f'undefined encoding for "{char}" (U+{(ord(char)):04X})') from err

    return codes


def __to_telecode_combined(unicode):
    """Encode unicode to telecode using both mainland and Taiwan codebooks.
    """
    codes = []
    for char in unicode:
        try:
            cnindex = _MAINLAND_CODEBOOK.index(char)
        except ValueError:
            cnindex = 0

        try:
            twindex = _TAIWAN_CODEBOOK.index(char)
        except ValueError:
            twindex = 0

        if cnindex and twindex:
            if cnindex == twindex:
                codes.append(cnindex)
            else:
                raise LookupError(f'ambiguous encoding for "{char}" (U+{(ord(char)):04X})')
        elif cnindex:
            codes.append(cnindex)
        elif twindex:
            codes.append(twindex)
        else:
            raise LookupError(f'undefined encoding for "{char}" (U+{(ord(char)):04X})')

    return codes


def to_unicode(telecode, encoding=None):
    """Decode telecode to unicode.

    >>> to_unicode(['0022', '2429', '0207', '1873'])
    '中文信息'

    Because of differences between simplified and traditional characters, the
    same telecode may decode to two completely different unicode strings.
    `encoding` should be used to specify whether the 'mainland' or 'taiwan'
    codebook should be used. If not specified, and there is ambiguity in the
    decoding, a LookupError is raised.
    >>> to_unicode(['5618', '1947', '0948'], encoding="mainland")
    '萧爱国'

    >>> to_unicode(['5618', '1947', '0948'], encoding="taiwan")
    '蕭愛國'

    >>> to_unicode(['5618', '1947', '0948'])
    Traceback (most recent call last):
     ...
    LookupError: ambiguous decoding for "5618"

    There are two cases: '塵' (U+5875) and '萼' (U+843C) where the database
    gives two different Taiwan telegraph codes (there are no such cases for
    mainland).

    In the case of '塵', there is no corresponding mainland code;
    only two Taiwan codes ('1057' and '7775'). Mainland uses those codes for
    two completely different characters.
    >>> to_unicode(['1057', '7775'], encoding="taiwan")
    '塵塵'

    >>> to_unicode(['1057', '7775'], encoding="mainland")
    '尘铈'

    >>> to_unicode(['1057'])
    Traceback (most recent call last):
     ...
    LookupError: ambiguous decoding for "1057"

    >>> to_unicode(['7775'])
    Traceback (most recent call last):
     ...
    LookupError: ambiguous decoding for "7775"

    In the case of '萼', mainland and one of the Taiwan codes is '5501', but
    Taiwan uses a secondary code '9795'. Since both encodings accept '5501' and
    '9795' is unique to the Taiwan codebook, both can be decoded without an
    explicit encoding.
    >>> to_unicode(['5501', '9795'])
    '萼萼'

    >>> to_unicode(['5501', '9795'], encoding="taiwan")
    '萼萼'

    >>> to_unicode(['5501'], encoding="mainland")
    '萼'
    """
    if not encoding:
        chars = __to_unicode_combined(telecode)
    elif encoding.lower() == "mainland":
        chars = __to_unicode_single(telecode, _MAINLAND_CODEBOOK)
    elif encoding.lower() == "taiwan":
        chars = __to_unicode_single(telecode, _TAIWAN_CODEBOOK)
    else:
        raise NotImplementedError('undefined encoding type "encoding"')

    return "".join(chars)


def __to_unicode_single(telecode, codebook):
    """Decode telecode to unicode using either mainland or Taiwan codebooks.
    """
    chars = []
    for code in telecode:
        char = codebook[int(code)]
        if char.isspace():
            raise LookupError(f'undefined decoding for "{code}"')

        chars.append(char)

    return chars


def __to_unicode_combined(telecode):
    """Decode telecode to unicode using both mainland and Taiwan codebooks.
    """
    chars = []
    for code in telecode:
        cnchar = _MAINLAND_CODEBOOK[int(code)]
        twchar = _TAIWAN_CODEBOOK[int(code)]
        if cnchar == twchar:
            if cnchar.isspace() and twchar.isspace():
                raise LookupError(f'undefined decoding for "{code}"')
            chars.append(cnchar)
        elif cnchar.isspace():
            chars.append(twchar)
        elif twchar.isspace():
            chars.append(cnchar)
        else:
            raise LookupError(f'ambiguous decoding for "{code}"')

    return chars


def load_unihan_data(file):
    """Load codebook from "Other Mappings" Unihan database dump.

    `file` must be a file-like object of the tab-delimited dump.

    Returns a dict of Unicode ordinals (integers) and a pair of mainland and
    Taiwan four-digit telegraph code.

    There are two cases: '塵' (U+5875) and '萼' (U+843C) where the database
    gives two different Taiwan telegraph codes (there are no such cases for
    mainland). In these cases, the Taiwan code is itself a pair.

    See <https://www.unicode.org/reports/tr38/> and
    <https://unicode.org/reports/tr44/> for descriptions of the dump.
    """
    codebook = {}
    for line in file:
        stline = line.strip()
        if not stline or line.startswith("#"):
            continue

        codepoint, field, value = stline.split(sep="\t", maxsplit=2)
        if field in ("kMainlandTelegraph", "kTaiwanTelegraph"):
            char = int(codepoint.split("+")[1], base=16)
            cncode, twcode = codebook.get(char, ('', ''))
            if field == "kMainlandTelegraph":
                codes = (value, twcode)
            elif field == "kTaiwanTelegraph":
                if " " in value:
                    codes = (cncode, value.split())
                else:
                    codes = (cncode, value)

            codebook[char] = codes

    return codebook


def load_unihan_zip(file):
    """Load codebook from Unihan database dump zip.

    Loads codebook from "Other Mappings" from the Unihan zip file downloaded
    from at <https://www.unicode.org/Public/UNIDATA/Unihan.zip>.

    `file` should be a filename or file-like object. If a file-like object, it
    must be seekable.
    """
    with ZipFile(file) as zipf:
        with zipf.open("Unihan_OtherMappings.txt", mode="r") as txt:
            return load_unihan_data(TextIOWrapper(txt, encoding="utf-8"))


def _generate_codebooks_strings(unihan):
    """Generate codebook strings from Unihan database dump.

    Codebook strings are generated so the NNNN character in the string
    corresponds to the telecode NNNN.
    """
    cnbook = ["\u3000"]*10000
    twbook = ["\u3000"]*10000
    for codepoint, (cncode, twcode) in unihan.items():
        if cncode:
            cnbook[int(cncode)] = chr(codepoint)

        if twcode:
            if isinstance(twcode, str):
                twbook[int(twcode)] = chr(codepoint)
            else:
                for code in twcode:
                    twbook[int(code)] = chr(codepoint)

    return "".join(cnbook), "".join(twbook)


_MAINLAND_CODEBOOK = """
　一丁七丈三上下不丐丑且丕世丙丞丢並丏丨个丫中丰　串锕丶锿丸丹主砹丿乂乃久之乍乎
乏乖乘桉乙乜九乞也　乳乾乱凼亅了予事苯二于云互五井　　些亚亟吡亠亡亢交亥亦亨享京
亭亮亳亶　醭人什仁仃仄仆仇今介仍佣佬仔仕他仗付仙仝仞仡仟代令以仰仲仳仵件价任份仿
企伉伊伋伍伎伏伐休伙伯估你伴伶伸伺伻似倮佃但　位低住佐佑　何佗余佘佚佛作佞佟佺　
佩伢佯佳　佶佝佻佾使侃来侈例侍侏侑侔仑侗供依　伕佰侮侯侵侣便　促俄俊俎俏俐俑俗俘
俚佡保俟侠俞俫信修俶伥働倌倬俯俱俳俵俸俺俾仓　倍俩倏们倒　倘候倚倜　借倡　值倥倦
倨倩倪伦倭偈偎傻　偃假伟偏偕做停健　侧侦偶仫偷伧傀傅傍傑傒傈伞备　　　催　傲传伛
债伤倾偻仅　佥僳像　　僦偾　侨　僖僚伪侥僧僭僮　僵　僻　仪侬亿儆侩俭傤　僰儋儇傧
儒俦侪　　　偿优储　俪傥俨　儿兀允元兄充兆先光　克兑免兔　兕兖兜兢　入内全两　钚
八公六兮共兵其具典兼冀糍冂冉册再冏冇　冒冕镩冖冗　冠冢冤冥幂耖冫冬冰冲冱冶冷冮冽
况凄准净凉冼凋凌冻　凑　凛凝决几凡凭凯凳凰茌凵凶凸凹　出函菪刀刁刃分切刈刊刎刑划
刖列刨初删判别　利剁刮到刲刳　制刷券刹刺　剃刭则　削刻前剜剌剡剔剖刬刚剥剩剪剐副
割剀创　剽剿　　　剧劈刘刽　剑剂劓劘　剅力功加劣助努劫劬劭効劻劾劼劲勃勐勇勉勍勒
动勖勘务胜劳　募势　勤　勚勰勳劢励勷劝锝勹勺匀勿　包匈匊匍匏匐勾匕化北匙碲匚匜匝
　匠匡匣匪汇匮匦　　啶匸匹匾匿区铥十千廿卅升午卉半卑卒卓协南博　卜卞占卡卣卦氡卩
　　卯印危　却卵卷卸卺　卮即　卿胨厂厄　　　厘厍厚厝原厕厥　厌厮厉厦胴厶　去叁参
　塅又叉及友反叔取受叙叛叟　丛叠口古句另叨叩只叫召叭叮叱可台史右叵叶司吁吃各合吉
吊同名后吏吐向吓　君吝吞吟吠否吩咐吆含吭吮呈吴吵呐吸吹告吻吼吾呀吕呃呆咂呢呦呋周
咒吧呱　味呵呶呷呻呼命咀咄咆咕和咎咏咋咖哎咤响咪咧咨咫咬咯咱咳　咸　咽哀品哂哄啊
哇哈哉哪咿员哥唔哦哩哭哮哲哺哼哽哿唁唆　唉唐唇哨啦唏售唯唱唳唾啁　啄商问启啖啥啜
哑唬啤啡啻啼喁喀喂喃善喆喇喈喉喊喏　喋喑喘喙唤喜喝唧喧喻丧乔单啾喹嗅吗啬嗑嗓嗔呜
嗪嗜嗟嗣嗤喔喟哟　嗡呛嗉嗒喽　叹嘈嘉嘏嘛唛　啧尝嘘噻嚎嘎呕嗷嗽嗾嘬哗哔叽啸嘲嘴哓
嘶嗥嘹嘻嘿　噌噍噎噢　噤器噩噪噫噬嗳哙喷噶哝哕吨噱咛嚅　嚏啮嚚　冁　　　　严咙嘤
嚼啭嗫嚣嚷　囊呓嘱　叻囗回囚四囱因囤困囫囷囹固囿圃圄圈圉国　囵圐圙围园圆图团圜　
土在圩圬圭圮地圻址圾坟均坊坍坎坏坐坑坂坌坡坤坦坭坩坷坼垂坪坫坰坳型垓坬垠垢垣垃坯
垛坨埃埋城埒垮埏域埠垧埭垡执培基堂坚堆垩埤埴埵埸堃堙堞堡堠堤堪尧报埔场堵埝堰垾塍
块茔塌塑塔墓塚　塘塞填坞垲埙埘堼坝尘堑　塾塂墀墁境墅墉垫墄埫　坠　增墟墨墩堕　　
塄塆墈垦壁壅坛　　壑压壕　垒圹　垄垆　壤　圳士壬壮壹壶　寿壸椴夂夆簖夊夏砘　跺夕
外夙多夜够梦夤夥婀大夭天太夫夬央失夯夷夸夹奄奇奈奉奎奏奂契奔奕奓套奚锇奘奠　奢奥
奁夺奖奭奋奀女奴奶奸好妁如妃妄妊妒妍妓妖妗妙妆妣妤妥妨妯妹妻妾姆姊始姗姐姑姒姓妲
妮委姚姜姝　　姣　姥姨　侄姬　姻娃姿威娉姮　娌娑娘娱娜娟娠娣娥娩娓娼姹娶娄婆婉婊
婕婚婢　妇婪娅她妳婼婷婺媒媚媛　　娲　　媖媳媵媸媪妈媾　嫁嫂嫄嫉　嫌媲　嫖妪嫠嫡
嫣嫦嫩嫪嫘嫚嫜嫫　妫娆嬉婵娇媭嬖嬗嫱嬛嬴嫔嬷　嬲　婴婶孀　娈妞子孑孔孕孓字存孚孛
孜孝孟季孤孥孩孙孰孱孳学孺　孪孵宀宁它宄　宅宇守安宋完宏宓宕宗官宙定宛宜客宣室宥
宦宬宫宰害宴宵家宸容　　宿　寂　寄寅密寇　富寐寒寓　　　　寞察寡寝寤寥实寨　　审
写宽寮寰宠宝宧寸寺封射尅将专尉尊寻对导蒽小少尔尖尚　　尕尢尤　尪就尰尴尬铒尸尹尺
尻尼尾尿局屁居届屈屉屋　屎屐屑展屏屝屠屡屣层履　屦　属　砩屮屯岳山屹屺峁岌岐岑岔
峿冈岢岈岩岫岱岵岷岸岣峒峙峋峨峭峰岛峻峡峓岘峪崃崇崎岽崑崔崖崙岗崛峥崩崚崧崦嵇崆
嵋嵫嵊嵌峧嵎岚崀崅嵩嵝嵬嵯崌嶂崭岖嶒嵚嵘峤崤峄嶙嶷岭屿崾巉嵛巍峦嶅巅巖崂巛川州巡
巢镄工左巧巨巫差酚己巳已巴　巷巽钆巾币市布帆帋帑帕希帖帗帘帙帚帛帔帝帡　帅师席帨
帐带帷常帽帏幄幅帧　幌幔幕帼帻帜幡幢　幪帮帱　　　幛干平年并幸　矸幺幻幼幽　酐广
庀庹庇床庋序底庖店庚府庠庥度座库庭　庵庶康庸庾　　　厢　廑廈廉廊廋厩廓廖厨　　廛
庙　庑废　廨廪庐　厅庞锆廴延廷　建　　廾　弁弄　弈弊茛弋弍式弑瀔弓　引弗弛弟弢　
弦弧弩　　弭弱　张　强　弼彀弹　弥弯弘彐彖彗彘　彝彟臌彡形彤彦彧彩彪　彬彭彰影彨
铪彳彷役彼　往征徂待徇很徉徊律　徐径徒得徘徙徜从徕御　徨复循徬徭微徯徵德彻徼徽焓
心必忉忌忍忒忖志忘忐忑忙忝忠忡恬快忭忮念忱忸忤忻忽忿怍怎怏怒怕怖怗怙怛思怠怡急怦
性怨怩怪怫怯　怵　您怔恁恂恃恒惦　恍恐恕恙恚恝恢恣恤　恧恨恩恪恫恭息恰悃　悄悦悌
悍悒悔悖悚悉悛悝悮悟悠患　　悱　悲悴怅闷悸悻悼　　　情惆惇　惑惓惕惘惙惚　惜　惟
惠恶悰惋惰恼恽想惴惶　惹惺恻愀愁愆愈愉　愍愎意　愔愕愚爱惬感愠愧悫愫　怆恺慎忾愿
恿　　　慈慊态慌　慓慕惨　慝惭恸慢惯　慧慨怂虑慰悭　慵庆慷　　　忧　惫怜　憔惮憎
憝愤憧憨憩憬悯怃　宪　忆　憾　　懂恳懈应懊懋怿懔　愦　　　怼懑　懦惩懿懵懒怀悬忏
惧　慑恋恹戆　戈戊戌戍戎成我戒戋戕或戚戛戟戢戥戡　戬截戳戮战戏戴戤户戾房所戽扁扃
　扆扇扈扉　槲手才扎扑扒打扔托扛扠拤　扣扭扮扯　扳扶批抵扼找承技　抄　抉把抑抒抓
　投抖抗折抨披抬抱抿抹押抽拂拄拆拇担拈拉拊抛拌拍　拐拎拒拓拔　拖拗拘拙拚招拜捂拮
拭括拱拯拳拴拷拽拾拿持挂指挈按挎挑挖拼挨挪挫振捅挹挺挼挽挟　捆捉捋捌捍掂捐挣捕挲
捎捧　捩扪捺捭据　捱　捶捷揍捻　掀扫掇授掉掊掌掏掎掐排掖掘　掠　探掣接控推掩措掬
掯抡　　　拣揄揆揉描捏提插揖扬换　揠搽握揣揩揪揭挥　援　掾搞　搧　　　损搏搒搓搔
摇捣搜搠　　搦　搪搬搭搴摔抢搐　掺撂摘搂撑摧摩摭挚抠抟摸摹摺掴摒　撅　　撩撇捞　
撒挠撕撙　　撞撤拨抚播撮撰　撬掼攉挞撼挝拥擂掳擅择击挡操擎拧擒　擗擘　撷搀挤　擢
　擦拟摈搁撵擭掷扩摆擞扰攀摅拦撄攘携摄拢攒挛摊搅攫揽　拃支　塃攴收　攸改攻放政故
效敉　教敏救敕敖败　　敝敞敢散敦夐敬敲整敌敷数　　敛毙敩　文斌斐斑斓蟥斗料斛斜斝
斟斡斢斤斥斧斨斩斯　新断　　　方於施　旎旁旂旃旄旅旆　旋旌族旖旒　　　旗烩无既　
日旦旨早旬旭旰旱晒旺昌昂昆昃明昏易昔晗昉昕昝星映春昧昨昭是昱昴昵昶晁时晃晋晌晏晚
晢昼晞晡晤晨晦暎普景晰晳晴晶晷智晬暄暇暍暑暖暗旸暝畅晕晖暂旻暮　暴　暹暨晓暾　　
昙　曙　曛曜曝　旷曦昽曩　昇曰曲曳更曷书曹曼曾替最会　　月有朋服朔朐朓　朕朗望　
朝期　朦胧耠木未末本札术朱朴朵朽杆杈杷杉杌李杏机材村杓杖柈杜杞束梠栓杪杭柿杯杰东
杲杳朿杵棵杼松板枉析枕林枙枚果枝　枇枋　枘枯　枳枵架枷枸　　柁柄柏某柑柒染柔柘柙
柚柜柝柞　柢查柬柯柮柰柱柳柴栅枰　樋栗校栩株核　根槾格栽桀桁桂桃桅框案桌桎桐桑桓
桔桕栖栲栳桄桫桴　桶桷　梃梁梅梆梏梓栀梗　　条枭梢梧梨梭梯梱械棁梳梵　　桯弃棉棋
棍棒棕枨枣棘棚栋棠棣栈棫棬森棰楦　棹棺椁棻棼　椅植椎椒棐棓棱棨椐椓　椰椹椽椿　杨
枫楔栉　　　楚楞楝楠榆楢楣楫业楯楮极楷楹　　槠桢楩楸榔榕榖榘榛榜　榧榨榫榭荣榱榴
榻榾槁槅槊构槌枪槎槐　　　　榷榼樑　椠　　概桨槔槽槿桩乐樊楼橦标　枢樟模样槥枞　
樗　檩　樵树樽樾橄桡桥橐橙橛　橡　横樨柠椭桦　檖橘檀柽檄檐档桧槚　檠检樯檬梼　槟
槛　　　橹榈　椟橼栎　枥榇棂栊　栏樱权　栾榄　柩欠次欣　欲款欷欹欺钦　歃歆歇　歉
歌　欧歔　歙　　欤　欢　止正此步武歪歧岁历归钬歹死殁　殂殃殄殆殉殊殍殖残殕殛殒殇
殚　殪殓殡歼镓殳段殷杀　　殿毁毅殴椵母毋每毒毓　比毖毗　鲣毛毡　毫　毯毳牦氅　毹
　　氍　氏氐民氓氯气氛　氤氲浠水　永氾汁汀求　汗污汛汜汝江池汊汐汔汕汞汨汪汰汲汴
汶汹　汾沁沂汽沃沈沉沌　沐没沔沖　沙沚沛沆沓汩汭沅　沫沮沱河沸油治沼沽沾沿洺泄泵
泅泔泆泉泊泌泓法泗洩　泛泠泡波泣泥注泫泯泮泰泱　泳沭　泐泖　洄浐洋浕洎洒洗洛浉洞
津洧汧洪洫洮洲洱洳洵浈洸活洼洽派洨流洙洚洹浙浚浣浦浩浪浮浴海浸浃浬泾消涉淳涓涔涕
涞涢浡浜浥涂涅湟涑涯液涵涸　涿淅淆淇淋淑渊淘淙泪淝淡淤淦浄沦淫淬淮浛深菏混清淹浅
添涎涪涴淀淄涠淞浯涭滧涣渚減渝渠渡渣渤渥涡测渭港　渴游渺浑湃湄　　湍湎湖湘湛　湧
湫湮汤湲　濉　　湓湔湜　　源準溵溜沟溟溠溢　溥溧　溪温溯溱溲溶溷溺　溽滁滂滃沧灭
滋涤荥滑滓滔滕　溘滇滘　　滞渗　滴沪浒洑滚满渔漂漆漏溉漓演　　漠汉涟漪漫渍　淌漱
涨漳渐漾浆　　滹　漉溎沤漦漩漯溆漶溇漕颍泼洁潘潜潟潢涧润潦潭潮溃潼潴潸潺涩澄浇涝
澈澔澌澎潖澛潞　　　浔潵澍澂　沩澡　　泽浍澳澹激浊濂浓渑　滪澧　　澴　　澶澼泞　
湿　　　济濠濡涛滥濬濮濯潍滨泻　濞溅泺滤渎浏瀑　濒　瀚瀛沥潇　濑泸　瀣瀼　瀍泷　
　潋澜　溁瀹　灌沣　滠　滩灏湾滟灞滦炸火灰灶灸灿灼　灾炊炎炒炕炙炘炞炫炬炭炮炯　
炱炳炷　畑烈　乌　烙烘烜烝烟烹烺烽焌焙焚焜　焦焰然　焠焉煅焊炼煊煌煎煮炜熙　煜煞
茕煤焕煦照烦煨　炀煽　熄　　熊熏荧　熟熔熨熬　热熠颎　　熹炽　　　　烫燃　灯燎烧
燔燕营燠燥　燧　烛　燮燹烬燿焘爆　烁　炉烂　爝爟焮炖焖爨烤爪争　爬爰为爵睑父爹爷
爸爻爽　趼爿　牂牁　藠片版　牌牒　牖牍　牙肼牛牝牟牡牢牣牧　物　牯牲犋牷特牵　犀
犁　犍犒荦犊牺　　犬犯犴状狂狃狄狁狎狐狗狙狡　狠狩狴狸狭狼狈狻狺狷狢猁猖猗狰猛猜
猝猞猊　猢猥猩猪猫猴犹猷猔猱猺狲猾猿　狱狮獍獐獒獗　　独狯獬獠狝获獯　犷猎兽獭献
　狞猡玄率　　锔玉王　玕玔玖玟玠玢玦珏玩玫玲玳玷珂　珈珉玻珀珊珍　　珞　珠珙珖珥
珣珩珪班珧珮珽现球琅理琇琉珶　琊琕　琚琛琢琤琥琦琨琪　琮琯琳琴琶琵　琬　琲玮瑕瑙
瑚瑛瑜瑞瑟　　瑁　　瑗琐瑶莹玛瑰玱　　瑱　　璀璃璋　瑾　璆　　琎璇璐璜玑璘璞璟璠
璧璨　环　珰玺璲瑸玙　珑璎　　瓒　　　　瓜瓞瓠瓢瓣瓤　瓦瓮瓴瓶瓷瓻甃甄　瓿瓯甍　
甑甓　　　　瓩甘甚甜　咔生甡产甥甦　用甪甫甬甯甩田由甲申男甸　甾畀畋界畎畏町　　
　畔畚畛畜亩留　毕畤略畦番画畬畯　　榃畹　当畸畿疆畴　锎疋　疏　疑钪疒疔痃痉疚疝
痠疣疤疥疫痄疲疳疴疵疸疹疼疽疾　病症痂痊疰痍痒痔痕痧痘痛痞痣　痢痱痰痳痴痹痼　痿
瘀瘁　　　疯疡　瘝瘐痪瘕　瘗瘟瘠疮瘢瘤瘥瘦疟　瘸瘰瘳瘴瘵瘘瘼疗癃痨痫癌癖　　疠瘩
癜疖　　　瘪瘿疬癞癣瘾癯痈瘫癫疙癶癸登发钶白百皂的皆皇皈皋皎皓皖　　皑皤皞　　　
　氪皮皴　皲皱　醌皿盂　盅盆盈益　盍盎盒盔盛盗盝盏盟　尽监盘盥卢盦　　盪盬蛞目盲
直相盼盾省眄眇眈眉盯看盻眨盱睬眛真眠瞄　眦眩眙眯眵　眶眷眸眺眼　着　睨睇　瞅　睚
睛睁睐睾睡睢督睦睫瞌　睥睹睿瞀　　瞋　瞎瞑瞒瞠瞪瞥瞧瞬瞳　瞭瞰瞆瞻瞽瞿　矍眬矗　
　瞩眭矛矜矞砬矢矣知矧矩短矮　矫　镴石　矼砆矻砂砉砌砍砑砒砭砟砸砥斫砦破　砜砧砼
砰　研硎硁硝硖砗硫硬碘砚确碍碌碎硼碗　碇碔碑碓　碡　碉砀碟碣碧硕磜　碰　码碾磁磅
磊礅磋磐磙磔磕磉硙碴硵砖碛磨磬矶磲磺硗礁磷　础　　矾礳磴　矿砺砾砻礴碱示礽社祀祁
祆祇祈祉　　祊　祐祓　祖　祚祛祜祝神祟祠　祲祥祧票祭　　祺禄禀禁　祸祯福禘禊　　
祎祃　　禠　禧禅　礼祢祷禳　铼禸禹禺离禽镧禾秃秀私　秉秆秋种科秕秒　秘　租　秣秤
秦秧秩秫秭　　秸移稀稂税　程　稍　稔稗稞稚　　　稠　稹　称稷稻稼稽稿　穄穆　　稣
积颖穗　穑　秽秾　稳　穞穰罱穴　究穸穹突空　穿窀窄窅窆窈　　窒窕窖　窗窘窟窠窨窝
　窬穷窑窳窎窭窸窣窥窾　　窜窍窦　窃蒗立竑站　　竟章竣童竦竖竭端竞铑竹竺竽竿笄笈
笊笏笑笙笛笞笤笠笥符笨笋笪笫第笮笆　笱笳筅笔筇等筊筋筌　筎筏筐筑筒　答策筠　　筷
笕　筮筲　筵　筱笺　　箍箇箔箕算　箝　管筝箐　　　箜　箬箭　箱箴箸　节篁　篆篇　
箧　　篙篚篝筿篡笃　　　筛篦篪篲筚　　篷箦簕簇簋篓簌簏篌篾簃　　簟箪簠简篑　簦簧
　簪箫　簸　　签　簿　篮　筹籍　籐　　籀箓　篯箨籁笼　　　　笾　箩篱　　篰米　　
粉粒粕粗粘粟粢粤粥籼　粱粲粹粳　粼精糈糊　糕糇糖糗糜糁粪糟糠籽糙　　糯粝籴粑　粜
　糸系纠纪纣约红纡纥纨纫紊纹　缐　纴　　纳纽纾纯纱纮纸级纷纭素纺索紫缏　　累细缩
绅绍绀绋　绐绌终　组绊绂　　结绝　　绔绞络绚给绒　絮绖统丝绛　绢　　绑绨绣绠　　
绥　经绡综绿绸綦线绶维綮绾　纲绷缀　纶绺绮绽绰　　　绫缁紧绯绻　绪缄缉绵缎缔缘　
缌　编缓缅纬练　缊缃　缗　缈　缇萦缙缢缒绉缞缚缜缛县缣繁缟　　缝纵缧　缦絷缕缥縻
总绩　缫缪繇缡　　　织缮　缭　绕　　缯绳绘　茧缰缳缴绎辫　继　纂缤缱　颣缬缵续　
纤缠纩　缨　纛　缆绦缶缸缺　　　　罄罅　　罂罍　罐　网罔罕罘　　罟罡　　罩罪　置
罚罨署　　　骂罢罹　罽　罗罴　羁鳓羊羌美羑羔　　羚羝羞　群羡义羯羲羧　羸羹羼羽翀
翁翅翊翌翎习翔翕　翟翠翡　翥翦翩羿翚翮　翰翳翘翱翻翼　　　耀喱老考耄者耆　耋　而
耍　耐　唡耒耔耕耗耘耙耜耢　　耩耦耨耧耰钌耳耶耻耽耿聃聆聊聒圣聘聚闻联聪声耸聩聂
职　聋啉聿肄肃肆肇呤馏肉肋肌肓肖肘肚肛肝股肢肥胺肩肫肯肱育肴朊肺胃胄背胂胔胍胎　
胖胙胚胳胝胞胰脒胭胯胡胥胸胼能胾脂腺胁　胱　脊脚脘胫脆腈　脧脩膨脱脬脯胀脾腆腊腋
肾腐腑腓腔腕腥脑腴肿腮脿腰腱肠腹腠腿膀膂腩膏肷　膈膊腘肤膛膜膝胶腻　膳膺　　膻脍
脓臀臂　臆脸臊脐　　臃胪　脏脔胤臣卧臧临栌自臬臭　　镥至致　　臻氇臼臾舁舀舂舄舅
与兴举旧　摞舌舍舐舒舘舖舛舜舞　镅舟　舡航般舫　舷舵舶船舸　舳舴艇艋艄　　　艘舱
舣艟艨　舰舻酶艮良艰钔色　艳　艸艽艾芃芄芊芋芍芎芑芒芙芝芟芡艿芤芧芨芥芩芪芫芬芭
芮芯芰花芳芷芸芹刍芼芽莜芾苑茆苒苓苔苕苗苄苛苜苞苟苣苡若苦苎苫英苴苹苻　苾茀茁茂
范茄茈茅茇　茉茗荔茜　　茨茫茭茯茱兹茴茵茶　茸茹荀荃萄荆荸荇草　荏荐荑荒茝荄　　
荷荻荼荽莅　莎莒莓茎莘莞莠荚苋莆莨莩莪莫菟莉莽菀菁菅菇　菊菑　菖菔菘菠菜菩堇华菰
菱菲　莙菹菼菽萁萃萜莱萋萌萍萎龿菡菌萩　苌萼　萱莴萸萹落葆　菸著　葚葛葡董苇葩葫
葬葭药葱葳葵荤葸葺　蒂葑　　　莳蒙蒜蒡蒞蒟蒨　蒲蒸蒹蒺苍蒿荪蓁蓂蓄蓆蓉蓊盖蓖蓍蓏
蓑　蓐蓓萏蔌蒯　　　蓬莲蓰莼　蔻蔫芗蓼　　蓿　蔑蕻蔓　蔗蔚蒌　蔡蒋荫蔴　茑　荜蔽
蔬蕺　蕃蕉蕊荞莸蕖荛蕙　蕞　蒉蕨荡芜萧蕰薯蒇蕈　蕤　蓣　蕾　薢薄薅薇荟　蓟　蔷　
　薛孽薜　薨萨薪薤蘖薏薰薳薹荠　　　　藉荩藏藐蓝藁藕　　藜艺　藤藩　薮　蔼蔺　藻
　藿蕲蘅芦苏蕴　夔　萚藓蔹茏蘩兰　　蘧蘸萝蘼　　蘑虍虎虐　虔处虚虏虞号　虢　　亏
　醚虫虱虻虹虺蚓蚍蚕蚊蚋蚌蚣蚤蚧蚩蚪蚨蚯蚰蚱蚜蚶　蛄蛀蛆蛇蛉蛑蛋蛙蛛蛟蚴蛤蛩蛱蛭
蛾蛘蜂蜃蜇蜈　蜓蛸蛹蜕蜀蜉蜍蜊　蜘蜚蜜蜡蜣蜩蜥蜒蛔蜴蜞　螂蜢蜮蝎蛐蚀蝗蝘蝙蜅猬蝠
蜿蝥虾蝮　蝶蜷蟮蜻蝌　蜾蝣蝻蝴蜗融蠓蚂螨螟萤　蚝螃蛳螫　螺蝼螽　蛰蟊螬螭　螯螳蟀
蟆蝈蟋虮蟪蟒蟛蟠蝉　　蟹蚁蟾　蛏蠃　蚃蝇虿　蠕蠖蠛　　蠡蠢蛎蟏蠹蛊蠲　蛮虬血嘧　
衄衅　众　　嚜行衍　　衒　　街衙　　卫衡衢　衣表衫衰衲衷衩　衽衾衿袁袈袋袍袒袖　
袜　　　袤袪被袂　　　袱裁裂袅裎裀　裒裔裕裘裙补装裟　裨　裰裱裳裴裸裼裹　裾　褊
裈　褂褪褐褓袆褙褡褚褥　褫褰裤褦　褶亵　襄衮襁袢袄　　　褒　裣裆襟襦　　褴褛　　
衬　袭　襶　襾西要覃覆　　　镎见规觅视觇　觋觎　亲觊觏觐觑觃觉览觌觍观　氖角觔觖
觚　　解觥　觫　觱觳觞触　　　萘言订讣訇计讯讨讦训讪讫讬记讧　　讱讹讶讼诀讷访许
设讻　诉诃诊证　訾诂诋詈　讵诈诒诏评　诎诅词　诩询诣　试诗诧诟诡诠诘话该详诙诖诓
诔诛　　詹　认　诳誓诞诱诮语诚诫诬误诰诵诲说谁课谇诽谊訚调谄谆谈诿请诤诹谅诼论谂
　谀谞谝　　谔谛谐谏谕谘讳谙讽诸谚　谖诺谋谒谓谍　　谌誊诌　謇　谎谜谧谑谤谦谥讲
谢　谣　谡謦谟谪谬讴谨谩　　　　谲讥　　谮识谯谭　谱警　谵譬译议谴护诪誉读谫　变
　雠詟谗谶让　　　谠谳　　谷　豁　硇豆岂　豌豉豇　　　　　豕豚　象豢豨豪豫　豭豳
　铌豸豹豺貂貆貅貉貊貌　　貔　脲贝贞负财贡　贫货贪贩贯责贮　贰贵贬贷买贶费贴贻贸
贺贲贳赂赁贿赅资贾贼　赈赊宾赇赒赉赐　赏赍赔赓贤卖贱赋质账　赌赖赗　赚赙购赛赜　
贽赘赠赞　赡赢赆赃赑赎　赝赣　赤赦赧赫赭赪钕走赳赴赶起趁趄超越　赵趣趑趋趟蒎足趵
趾　趺　　跋　跌跎跏跑　跖跚跛距　跫跟　跣跨跪跬路踩跳跽踉踊　踏践踔踖踝踞踢踣踧
　踡踟踮　　踵踹蹓踽蹁蹂蹄踱蹀蹐蹇蹈蹉蹊跃跄跸　蹙　蹒　　　　蹯蹲蹴蹶跷　　蹬蹭
蹰躁　躅躇趸踌跻　躐踯　踬　跹蹑　躏蹦　身躬躭躲躯　　躺车轧轨军　轩轫轭软轱轸轴
轵轷轶轺轼较辂　载　　轾辄　辅轻　　辆辎辉辍辇辈轮辋　辊　辑辏输　辐　　　　辗舆
毂辖辕　辘　　转辙轿　　　　　轰辔轹轳　辛辜辟　辣　办辨辞辩耪辰辱农狍辵迂迄迅　
　迎近迓返　迢迤迥迦迨迪迫迭逄述　迷迸迹追迺退送适逃逅逆逋逯逍透逐逑途迳逖逗这通
逛逝逞速造逡逢连逭逮　进逵逶逸　逼遇遁遂遄逾　运遍过遏遐遑遒道达违遘遥遛逊递远　
遣遢　遨　遭遮　迟遴遵　迁选　遗　辽遽避邀迈邂还　迩邃邈边逻逦疱邑邛邗邙邕邢　那
邡邦邨邪邠邯邱　邴邳邵邶邸邰邽郁郅郇郊　郃郗郄　郛郎郡郢郤　郜郏部郭郴邮郯都郿鄂
邹鄄邬乡鄌郧鄙　鄢鄞鄠鄜邓　郑邻鄱邺郐郸　鄯邝酂酃酆郦郝酉酊酋酌配酎酒　酗酢酥酣
酤酡酩酪酬酲酵酷酸酴酹酞　醅　醇醉　醋醍醐醒　　酝　醢　醪医酱醮醯醴　醵醺　　　
酿　　　锫釆采释釉里重野量　锌金钊钉釜针钓钏钙　　钗　钯钝钩钤钠钞钮钧铃钹钰　钿
钜铉　钳铅钺钵　铇铏铰钲银铳铜钴铂铣铨铢铭铦衔铫锐钾销锈锉铹铤铗锋锓铀锄铓铺铻　
锯钢录锥锟锤锱铮锭钱锦锚锡锢错锛锜　锅锻铋铵锹键　锺锴镀锷锽锸锲　锾　　锁　　锘
　镃　铠镐镒镇镑镞链镝鏖铿锵镗镜镘镖镛镂铲　锑錾铙铧铝镪钟镫镌镰镯铁镮铎镍铛　铸
镬镔　鉴　钨　铄　镳　钥镭镶　镊𰾠锣　銮凿锰长蜱门闩闪闫闭闬开闳闰闲　间闵闸　阂
　阁阀闺闽阃阆闾阅阊阉阎阏阍阈阒　闱　阔阕阑阇阗阌闿阖阙闯　关　阓阐阚　阛闼　阜
阝　阡　　　阮　阱防阪阻阼阿陀陂附陋限陌降陔陉陛陕陞陟陡院阵除陪陬阴陲陈陴陵陶陷
陆　阳　隍　隅隆隈陧队隋阶隔陨　隗隘隙际障　　隧　险　隰隐隳陇随隶　苤隹隻隼雀雁
雄雅集雇雉隽雌雍雎　雒雕巂虽雘双雏杂　　　难钷雨雩雪雯　　　零雷雹电需霂　霄霈霉
霆震霍霎霏　霓霖霜霞　　雾霰霪　露　霸霹　霁　霾霭雳叇灵叆　青靖靓靛静镤非靠靡氆
面　　靥钎革靳靴鞅靶靰　　　鞍巩鞋　鞘　鞡　　鞠　鞫　鞭鞮　　鞲鞴　　鞑　鞯羟韦
韨韩韧　　　　　　韪韬韫　　炝韭　　　音韶韵　　　苘页顶顷项顸顺须颂颃预顽颁颔顿
顼　颀　颇领　颉颐颚　颏　头颒颊颕　颈颓频颗　　题额颜　颛　颡颠类　颟颢　顾颤显
颦颅颧粬风　飒飓飔　飏飖飕飘飙飗　　飞醛食　饥饤　飧饨饪饫饬饮饭饴饲饱饰饸饹饺饼
饻饷养饵餐饾　馁饿　馂馀馄　馅饯饽　馍馆　餮　　饧　饩　　馒　馑馈馔　　　饶饔饕
飨餍　馋　首馘馗炔香馥馨　　　蛲马驭冯驰驯驮驲驳　驻驽驹驾骀驸驶　　驼驷　　骈　
骇　骆　骃骎骏骔骋骓骍　　　骑　骐骛　骗骢　　　　骞腾驺　骟骚骝骡蓦骜骖骠驱　　
骅　骁　骄骕验　惊　　驿骤驴骧骥　骊　骨　骶肮骱骰骷骸骼　髀　髅　髑　体髋髓鞣高
铷髟髡　　髦　髫髭　髯鬃　髻髹　鬈　　　鬐　　鬘　　　鬟鬣鬓　鬥　　阋　阄铯鬯鬱
锶鬲　　　鬻　鬼魁魂魃魄　魅魏　　魈魍魉魑魔　魇唢鱼鱿鲁鲖鲂鲇鲋鲐鲊鲑鲔鲘鲍鲞鲜
鲛鲧鲤鲠鲨鲭鲵鲳鲓鲲鲸鲫鲩鳊鲽鳅　鲡鳃鳏鳒鲥鳍鳌鲶鳗鳀鳖鳝鲟鲎鲙鳣鳞鳔鳜鳘鲮鲈鲄
鸟　鸠凫　凤鸣鸢　鸱鸩鸨　鸦　　鸳鸮鸪鸯鸭鸰鸲鸿鸽　　鸺鹈鹅鹃鹄鹁鹉鹆鹌　鹊鹑　
鹏鹍　鹙鹕鹗鹜莺　鹤　鹡鹚鹒　鸧　鹘鹣鹢鹞鸡　鸥鹧　鹥鸷鸶　鹫鹰鹭鹪鹩　鹬鹯　鸴
鸬鹦鸾　鹳鹂　卤　　盐鹾熵鹿麂铈麀　麇麈麋　　麑麒麓　丽　　麝　麟　　涮麦　　　
麹蒴麻麽麾　黄　黉铊黍黏黎　溚黑黔默黛黜点黝黠黥黧　黯　　黡黩傣黹黻黼钛黾鼋　鼌
　　鼍钽鼎鼐　鼒　鼓　鼗　鼙　　羰鼠鼢　鼬鼯鼹鼷醣鼻　鼾　　铽齐斋　齑菾齿龀龁龂
龃龄龆龈　　龉龊　龋腭龌　龙厐龚龛舔龟烃龠　　楟酮茼烔钍佤烷烯螅氙酰鳕荨垭铱钇镱
铟铕　鳟蟑礃锗酯　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　
　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　
　万丘乒乓甭孬　　　么　乩　　亍亓亘　　　仂仉　伃　伽　伫　　　佼　佴佫　侢　　
　　　　伣俅伡　　　　侴　倢　倴倔　　偲　　　　偬　　偌　　　　僬　　　　　　儡
傩　　　　　　　　　　　　党凃　减　　冨　　　　剞劂刿　　　　　　勋　　匆　　　
吋　　吱　呎听　　　　咚　　咥哆咻　　呙　　呗唑　啗唪唼啐啍唶　　　　　唝　　　
　　　　　啯嘌唠噙　　　呒　哒　　　嚆　　嚭呖噜　喾啃　囝囡　圊　　　　　圯圪壳
　坻　　　坿垇　垞垤垚垌　垟垕　　埂　垸　　埌　埕　　　　　堉堎堀堌　　　塓　堍
　埚塬塱塝堽　塥　　墕　　　　垱　　　墙　　墒垅　　　　夼　　　　　　　　　　　
姘娒　　　　　　　婥　　媄媞　媮婿　　婳娴妩嫒　孃　　　　　　孖　　　　　　　　
屲屴屼　岙岍岜岨岬岞峃峇　　　峱　　崞崮　　崽崴峣　　　嶓崄　　　　岿　　　　　
巯　　幞　　　　　庄　　　廒　庼　　　　　异弌弎甙　　　忪　　　　　　　　　　　
　　　　　　　　　　　　　　　　　　　　　扡扦抃　　　　掰拶　　捃　　　挜　掮揸
　　　　　揎　　揶　　　搢揾　　　　　搡　　　　摷　搿　　挦　揿　掸　　　　　掱
　　　　　　　　　敜敫　　　斏　　　　　　　昀　昊　　　晟　晧　晾暋暌　　　晔暧
　　　　　　　　　　杠　　杅　　　杻　　　　　　　　　　　　　　栝　　　　桋栒栟
桬　　　　枧棑　　棸　　椑　楙楀楂　　　　　　　椝　椫橇　檎　桪枟槜檑　檴　　橱
　橥　榉　　　　　　　　　　　　　　　　　　　　　　　　　　　　毚毵　氞氟氨氧氥
氦氢氰　氮氩氕氘氚　　　　　　　　　　氿汆沄沇　　　　　　　　洴　涌　　　浤　　
浼淖　　　淠　　沨　　　渌淼渲　　溏　　溴滉滏　　　　　漷澉　　沵　滢瀌　　　　
　　　　　　　　　　　灺炅　　　　　　　　烱　焯　　焱　　　　　　　　　　　　熳
　燋　烨　　　　　　　　　　　　　　　　　牮　　　　犇犄　　　　　　　　　　　狨
　　　　　猆　　　　　猃　猕獾　　　　玥　　　珺　琼琷琰珐珲瑄瑂瑔瑢琏瑭　　　　
璩　瑷　　　　　　　　　　甏　　　　畈疃　　　　疢　　　　　　痤　瘃　瘄瘈瘌　　
瘭　　瘅癒　　　　　　　　　　癿　　　　　盹　　眚眢　　　　　　　　　睽　　瞟瞫
　　　　　　矬　矽　　砢砣砠　砝　　砷　　　　硐硅　　硭硪　　碚　　　碳碶　　　
　　磡　　硚　　礞硷硒　　　　　　　　　　禚　禤　　　　　　　　　稖　　　　　　
　　窿　　竜　　　　筘　　　　　　　篥　簉　　簰籝　　　　　　　　　　粞粦粮　　
粽糅　　　　　　糌　　　　纼　纰　绁　　　　　　绲缂　　　绬　缑　　　　　　　　
　　　　　　　　罾　芈　　　　　　　　　　　　　　　　聱　　　　肪胛　脉胆　　　
脞　　　　　脖　　　　腌　　　　膘　　　臑膑　　　　　　　　　　舢舨舺　　　　　
　　　　　　茓芘　　　荅　茬莦　　　　　　荝　　　葠蓪　　　苁蓷　　　薸　　　　
　　　　　　　　　　　　　虒　　　　　　　　　蚬　　　蝓　　蝤螓　　　　螗螵　　
蟢蠋蛴　蠭　　　　　　　　　　　　　　　裢　　　　　　　襞　　　　　　　　　觜　
　　　　　　　诇　　　　　　诨　　　　　谉谰　　　　　　　　　　　　　　　豮　　
　　贠　　　　　趱　　　跤　　　　踦踪　　　　　　蹩　　　蹼　躞　　　　　　　　
　　　轲　　　　辚　　　　　迮　　　　　邋　　　　　邘　　　郈　郚　　郫　　郓　
　郾　　　　　　　鄚鄣　　　　　　　　　　　　　　　　　醑　　　酾酽　　　钋钐　
钒　钑钫　钭钘　铍钻铆　　钼　　铐　　铬　　鋆　　锂　锒钡　　　铔　　锨　锬锖　
锠锞鍪　铡镁钖锳　　镏　　镉铩鏊蓥鎏　　　　　镦　锏镨镣　镡镢　　　锧鑫　　　　
　　　　　　　闹　　　　阽　　　　　　　　　　　　　　　　　　　靔　　靺　靼　　
鞨　　　　　　　　　　　　　　　颋颌　　　颙　　　　　　　　　　　　饦　　　　　
馊馎　　　　馃　　　　　　　　驵　　　　　　骦骉　　　　　髁　　　　　　　　　鲀
　鲅　鲒　　鲰鲻鲷鲗鳇鲝鳆鳄鲢鲦鲱鲴鳁　鳎鳢鲚鳙鳠鲿　鳛　　　　　　　　鸵鹓　鹖
　鹔　　鹴　　　　　麸　　　黟　　　　　　　　　　　　　　　　　　　　　　　　　
　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　
　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　
　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　
　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　
　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　
　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　
　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　
""".replace("\n", "")

_TAIWAN_CODEBOOK = """
　一丁七丈三上下不丐丑且丕世丙丞丢並　丨个丫中丰丱串　丶　丸丹主　丿乂乃久之乍乎
乏乖乘　乙乜九乞也乩乳乾亂氹亅了予事　二于云互五井亙况些亞亟　亠亡亢交亥亦亨享京
亭亮亳亶亹　人什仁仃仄仆仇今介仍仂仉仔仕他仗付仙仝仞仡仟代令以仰仲仳仵件价任份仿
企伉伊伋伍伎伏伐休伙伯估你伴伶伸伺伻似伽佃但佈位低住佐佑佔何佗余佘佚佛作佞佟佺佽
佩佪佯佳併佶佸佻佾使侃來侈例侍侏侑侔侖侗供依侷俔俅侮侯侵侶便係促俄俊俎俏俐俑俗俘
俚俛保俟俠俞倈信修俶倀倅倌倬俯俱俳俵俸俺俾倉個倍倆倏們倒倖倘候倚倜倂借倡倣值倥倦
倨倩倪倫倭偈偎偲偁偃假偉偏偕做停健偪側偵偶傎傔傖傀傅傍傑傒偫傘備傚傞𠉰催傭傲傳傴
債傷傾僂僅僇僉僊像僱僎僦僨僩僑僕僖僚偽僥僧僭僮儁僵價僻僾儀儂億儆儈儉儎儌僰儋儇儐
儒儔儕儗儘儤償優儲儳儷儻儼兡儿兀允元兄充兆先光兇克兌免兔兒兕兗兜兢兣入內全兩兪　
八公六兮共兵其具典兼冀　冂冉册再冏冓冑冒冕　冖冗冞冠冢冤冥冪　冫冬冰冲冱冶冷冸冽
况凄准凈凉凊凋凌凍减凑凓凜凝决几凡凭凱凳凰　凵凶凸凹𠙽出函　刀刁刃分切刈刋刎刑划
刖列刨初删判別刦利剁刮到刲刳刵制刷券刹刺剋剃剄則剉削刻前剜剞剡剔剖剗剛剝剩剪剮副
割剴創剸剽剿劂劃劄劇劈劉劊劌劍劑劓劖劚剅力功加劣助努劫劬劭効劻劾劼勁勃勅勇勉勍勒
動勖勘務勝勞勠募勢勣勤勦勩勰勳勱勵勷勸　勹勺勻勿匃包匈匊匍匏匐勾匕化北匙　匚匜匝
匟匠匡匣匪匯匱匭匳匵　匸匹匾匿區　十千卄卅升午卉半卑卒卓協南博卍卜卞占卡卣卦　卩
卬卭卯印危卲却卵卷卸卺卻卮卽　卿　厂厄厎厓厔厘厙厚厝原厠厥厫厭厮厲厦　厶厹去叁參
叅　又叉及友反叔取受叙叛叟叡叢叠口古句另叨叩只叫召叭叮叱可台史右叵叶司吁吃各合吉
吊同名后吏吐向吓吒君吝呑吟吠否吩咐吪含吭吮呈吳吵呐吸吹告吻吼吾呀呂呃呆咂呢呦呧周
咒呭呱呫味呵呶呷呻呼命咀咄咆咈和咎咏咋咍咡咤咢咥咧咨咫咬咯咱咳咷咸咺咽哀品哂哄哆
哇哈哉咻咿員哥唎哦哩哭哮哲哺哼哽哿唁唆唈唉唐哤哨唄唏售唯唱唳唾啁啣啄商問啓啖啗啜
啞唪唼啐啻啼喁喀喂喃善喆喇喈喉喊喏喓喋喑喘喙喚喜喝喞喧喻喪喬單啾嗃嗅嗎嗇嗑嗓嗔嗚
嗛嗜嗟嗣嗤喔喟喤喫喭嗆嗉嗒嗿嘅嘆嘈嘉嘏嘐嘑嘒嘖嘗噓嗹嘂嘎嘔嗷嗽嗾嘬嘩嗶嘰嘯嘲嘴嘵
嘶嘷嘹嘻嘿噉噌噍噎噢噏噤器噩噪噫噬噯噲噴噶噥噦噸噱嚀嚅嚇嚏嚙嚚嚲囅嚥嚬嚮嚳嚴嚨嚶
嚼囀囁囂嚷囉囊囈囑囓叻囗回囚四囪因囤困囫囷囹固囿圃圄圈圉國圅圇圂囮圍園圓圖團圜圕
土在圩圬圭圮地圻址坻坟均坊坍坎坏坐坑坂坌坡坤坦坭坵坷坼垂坪坫坰坳型垓垝垠垢垣垞垤
垛垚埃埋城埒埂埏域埠埦埭埶執培基堂堅堆堊埤埴埵埸堃堙堞堡堠堤堪堯報堲場堵堧堰堦塍
塊塋塌塑塔墓塚塗塘塞填塢塏塤塒塎塓塵塹塼塾塿墀墁境墅墉墊墄墍墐墜墝增墟墨墩墮墺墳
墠墫墦墾壁壅壇壈壎壑壓壕壖壘壙壞壟壚壜壤壩圳士壬壯壹壺壻壽壼　夂夆　夊夏　夔　夕
外夙多夜夠夢夤夥　大夭天太夫夬央失夯夷夸夾奄奇奈奉奎奏奐契奔奕奓套奚　奘奠奡奢奧
奩奪奬奭奮奀女奴奶奸好妁如妃妄妊妒姸妓妖妗妙妝妣妤妥妨妯妹妻妾姆姊始姍姐姑姒姓妲
妮委姚姜姝姞姙姣姤姥姨姦姪姬姅姻娃姿威娉姮姱娌娑娘娛娜娟娠娣娥娩娓娼姹娶婁婆婉婊
婕婚婢婣婦婪婭娵婐婞婷婺媒媚媛媟媢媧媊媕媖媳媵媸媼媽媾媿嫁嫂嫄嫉嫋嫌媲媺嫖嫗嫠嫡
嫣嫦嫩嫪嫘嫚嫜嫫嫺媯嬈嬉嬋嬌嬃嬖嬗嬙嬛嬴嬪嬷嬭嬲嬾嬰嬸孀孅孌妞子孑孔孕孖字存孚孛
孜孝孟季孤孥孩孫孰孱孳學孺孼孿孵宀宁它宄　宅宇守安宋完宏宓宕宗官宙定宛宜客宣室宥
宦宬宮宰害宴宵家宸容梥寀宿寁寂寃寄寅密寇寧富寐寒寓寔寖寘寎寞察寡寢寤寥實寨寠寙審
寫寬寮寰寵寶宧寸寺封射　將專尉尊尋對導　小少尔尖尚尠尟尕尢尤尨尪就尰尲尬　尸尹尺
尻尼尾尿局屁居屆屈屉屋屍屎屐屑展屛屝屠屢屣層履屧屨屩屬屭　屮屯岳山屹屺屼岌岐岑岔
岅岡岢岨岩岫岱岵岷岸岣峒峙峋峨峭峯島峻峽峓峴峹峢崇崎崐崑崔崖崙崗崛崢崩崚崧崦嵇崿
嵋嵫嵊嵌崶嵎嵐嵒崱嵩嶁嵬嵯嵾嶂嶄嶇嶒嶔嶸嶠嶞嶧嶙嶷嶺嶼嶽巉巋巍巒巘巔巖嶗巛川州巡
巢　工左巧巨巫差　己巳已巴巵巷巽　巾帀市布帆帋帑帕希帖帗帘帙帚帛帔帝帡帟帥師席帨
帳帶帷常帽幃幄幅幀幋幌幔幕幗幘幟幡幢幣幪幫幬幭幯幰幛干平年幷幸幹　幺幻幼幽幾　广
庀庄庇床庋序底庖店庚府庠庥度座庫庭庳庵庶康庸庾庬庴廁廂廌廑廈廉廊廋廏廓廖廚廕廝廛
廟廠廡廢廣廨廩廬廱廳龐　廴延廷廹建廻廼廾廿弁弄弇弈弊　弋弍式弑　弓弔引弗弛弟弢弣
弦弧弩弤弨弭弱弰張彄強弸弼彀彈彊彌彎弘彐彖彗彘彙彝彠　彡形彤彥彧彩彪彫彬彭彰影彲
　彳彷役彼彿往征徂待徇很徉徊律後徐徑徒得徘徙徜從徠御徧徨復循徬徭微徯徵德徹徼徽　
心必忉忌忍忒忖志忘忐忑忙忝忠忡忪快忭忮念忱忸忤忻忽忿怍怎怏怒怕怖怗怙怛思怠怡急怦
性怨怩怪怫怯怱怵怈怳怔恁恂恃恆恇恌恍恐恕恙恚恝恢恣恤恥恧恨恩恪恫恭息恰悃恉悄悦悌
悍悒悔悖悚悉悛悝悞悟悠患悤悁悱惪悲悴悵悶悸悻悼悽悾惄情惆惇惎惑惓惕惘惙惚惛惜惝惟
惠惡悰惋惰惱惲想惴惶惸惹惺惻愀愁愆愈愉愊愍愎意愒愔愕愚愛愜感愠愧慤愫愬愴愷慎愾愿
慂慄慆慇慈慊態慌慁慓慕慘慙慝慚慟慢慣慩慧慨慫慮慰慳慴慵慶慷慼慾憁憂慥憊憐憑憔憚憎
憝憤憧憨憩憬憫憮憯憲憍憶憸憾懃懆懂懇懈應懊懋懌懍懓憒憗憦憏懟懣懥懦懲懿懵懶懷懸懺
懼懽懾戀戁戇慜戈戊戌戍戎成我戒戔戕或戚戛戟戢戥戡戣戩截戳戮戰戲戴戤戸戾房所戽扁扃
扅扆扇扈扉扊　手才扎扑扒打扐托扛扠扢扦扣扭扮扯扱扳扶批抵扼找承技抃抄抆抉把抑抒抓
抔投抖抗折抨披抬抱抶抹押抽拂拄拆拇担拈拉拊拋拌拍拏拐拑拒拓拔拕拖拗拘拙拚招拜扤拮
拭括拱拯拳拴拷拽拾拿持挂指挈按挍挑挖拼挨挪挫振挶挹挺挼挽挾捄捆捉捋捌捍捚捐捓捕挲
捎捧捨捩捫捬捭据捲捱拼捶捷搸捻捽掀掃掇授掉掊掌掏掎掐排掖掘掛掠採探掣接控推掩措掬
掯掄掞掔掫揀揄揆揉描揸提揷揖揚換揜揠搽握揣揩揪揭揮揲援掽掾揅揗揰揫搆㩁損搏搒搓搔
摇搗搜搠搢搥搦搨搪搬搭搴搵搶搐摏搊搘摘摟摠摧摩摭摯摳摶摸摹摺摑摒摛撅摴摽撩撇撈撐
撒撓撕撙撚撝撞撤撥撫播撮撰撲撬擫撱撻撼撾擁擂擄擅擇擊擋操擎擐擒擔擗擘據擷攙擠擡擢
擣擦擬擯擱擥擭擲擴擺擻擾攀攄攔攖攘攜攝攟攢攣攤攪攫攬攩拃支攲　攴收攷攸改攻放政故
效敉敘教敏救敕敖敗敔敂敝敞敢散敦𢿌敬敲整敵敷數敺斁斂斃斅敭文斌斐斑斕　斗料斛斜斝
斟斡斢斤斥斧斨斬斯斮新斷斲斸　方於施斿旎旁旂旃旄旅旆旐旋旌族旖旒旜旛旟旝　无旣旡
日旦旨早旬旭旰旱旴旺昌昂昆昃明昏易昔昀昉昕昝星映春昧昨昭是昱昴昵昶晁時晃晉晌晏晚
晛晝晞晡晤晨晦晧普景晰晳晴晶晷智晬暄暇暍暑暖暗暘暝暢暈暉暫𣊓暮暱暴暵暹曁曉暾曀曈
曇曏曙曚曛曜曝曡曠曦曨曩曬昇曰曲曳更曷書曹曼曾替最會朅勗月有朋服朔朐朓朏朕朗望朞
朝期朢朦朧　木未末本札朮朱朴朶朽杆𭩚杇杉杌李杏　材村杓杖杕杜杞束杠杗杪杭柿杯杰東
杲杳杶杵杝杼松板枉析枕林枙枚果枝枤枇枋枌枘枯枲枳枵架枷枸柎枻柁柄柏某柑柒染柔柘柙
柚柜柝柞柟柢查柬柯柮柰柱柳柴柵枰枹柷栗校栩株核栱根栻格栽桀桁桂桃桅框案桌桎桐桑桓
桔桕栖栲栳桄桫桴桹桶桷桿梃梁梅梆梏梓梔梗桚梜條梟梢梧棃梭梯梱械棁梳梵桮梐桯棄棉棋
棍棒棕棖棗棘棚棟棠棣棧棫棬森棰楦棲棹棺椁棻棼椀椅植椎椒棐棓棱棨椐椓椷椰椹椽椿楅楊
楓楔櫛楗楙楘楚楞楝楠榆楢楣楫業楯楮極楷楹椶椸楛楨楩楸榔榕榖榘榛榜榦榧榨榫榭榮榱榴
榻榾槁槅槊構槌槍槎槐槓榎榤榥榷榼樑槃槧槨槩槪槳橰槽槿樁樂樊樓樕標樛樞樟模樣槥樅樏
樗槱樲樸樵樹樽樾橄橈橋橐橙橛機橡橧横樨檸橢樺橁檖橘檀檉檄檐檔檜檟檝檠檢檣檬檮檯檳
檻櫂櫃櫈櫓櫚櫜櫝櫞櫟櫱櫪櫬櫺櫳櫽欄櫻權欝欒欖欃柩欠次欣欬欲款欷欹欺欽欿歃歆歇歕歉
歌歎歐歔欻歙歛歝歟歠歡歞止正此步武歪歧歲歷歸　歹死歿殀殂殃殄殆殉殊殍殖殘殕殛殞殤
殫殢殪殮殯殲　殳段殷殺殼殽殿毀毅毆　母毋每毒毓　比毖毗毘　毛毡毧毫毬毯毳氂氅毸毹
氄氈氍毜氏氐民氓氯气氛氣氤氳浠水氷永氾汁汀求汎汗汚汛汜汝江池汊汐汔汕汞汨汪汰汲汴
汶汹決汾沁沂沄沃沈沉沌沍沐沒沔沖沗沙沚沛沆沓汩汭沅沬沫沮沱河沸油治沼沽沾沿泂泄況
泅泔泆泉泊泌泓法泗泚泙泛泠泡波泣泥注泫泯泮泰泱泲泳沭沴泐泖泝洄洊洋洌洎洒洗洛洟洞
津洧汧洪洫洮洲洱洳洵洶洸活洼洽派洿流洙洚洹浙浚浣浦浩浪浮浴海浸浹浼涇消涉涌涓涔涕
涖涘浡浜浥涂涅涒涑涯液涵涸涼涿淅淆淇淋淑淖淘淙淚淝淡淤淦淨淪淫淬淮淰深淟混清淹淺
添涎涪涴淀淄淒淞　淩淜渙渚減渝渠渡渣渤渥渦測渭港渰渴游渺渾湃湄湅湊湍湎湖湘湛湝湧
湫湮湯湲湱渟渢湑湓湔湜湏湩源準溛溜溝溟溠溢溤溥溧溦溪溫溯溱溲溶溷溺溼溽滁滂滃滄滅
滋滌滎滑滓滔滕溏溘滇滘滫滮滯滲澝滴滬滸滺滾滿漁漂漆漏漑漓演漘漙漠漢漣漪漫漬漭漰漱
漲漳漸漾漿潌滷滹漈漉漎漚漦漩漯漵漶漊漕潁潑潔潘潛潟潢㵎潤潦潭潮潰潼潴潸潺澀澄澆澇
澈澉澌澎潏潝潞潠潈濆潯潾澍澂澒潙澡澟澣澤澮澳澹激濁濓濃澠澥澦澧澨澰澴澱濇澶澼濘濔
濕濈濊濛濟濠濡濤濫濬濮濯濰濱瀉濩濞濺濼濾瀆瀏瀑瀁瀕灠瀚瀛瀝瀟瀠瀨瀘瀡瀣瀼瀋瀍瀧瀦
濳瀲瀾瀰瀵瀹瀺灌灃灉　灑灘灝灣灩灞灤炸火灰灶灸灺灼災灾炊炎炒炕炙炘炤炫炬炭炮炯炰
炱炳炷炧炁烈烋烏烕烖烘烜烝烟烹烺烽焌焙焚焜無焦焰然焞焠焫煅煇煉煊煌煎煮煒熙煖煜煞
𠙦煤煥煦照煩煨煏煬煽熀熄熅熇熊熏熒熛熟熔熨熬熯熱熠熲熸熺熹熾燀燂燐燖燙燃燄燈燎燒
燔燕營燠燥燦燧燬燭燻燮燹燼燿燾爆爇爍爓爐爛爚爝爟焮焯爥爨烤爪爭爮爬爰爲爵　父爹爺
爸爻爽爾　爿牀牂牁牆　片版牋牌牒牕牖牘牓牙　牛牝牟牡牢牣牧牴物牮牯牲牶牷特牽牿犀
犂犉犍犒犖犢犧犨牳犬犯犴狀狂狃狄狁狎狐狗狙狡狥狠狩狴狸狹狼狽狻狺狷猋猁猖猗猙猛猜
猝猞猊猘猢猥猩猪猫猴猶猷猨猱猺猻猾猿獃獄獅獍獐獒獗獘獧獨獪獬獠獮獲獯獳獷獵獸獺獻
玁獰玀玄率玅玈　玉王玎玕玔玖玟玠玢玦玨玩玫玲玳玷珂珇珈珉玻珀珊珍珌玼珞珓珠珙珖珥
珣珩珪班珧珮珽現球琅理琇琉珶珷琊琕琖琚琛琢琤琥琦琨琪琭琮琯琳琴琶琵琫琬玤琲瑋瑕瑙
瑚瑛瑜瑞瑟瑠瑀瑁瑇瑑瑗瑣瑶瑩瑪瑰瑲瑬瑯瑱瑳瑴璀璃璋瑽瑾璁璆璂璈璡璇璐璜璣璘璞璟璠
璧璨璯環璪璫璽璲璸璵瓊瓏瓔瓛璿瓚瓈瓀瓘璥瓜瓞瓠瓢瓣瓤　瓦瓮瓴甁瓷瓻甃甄甇瓿甌甍甎
甑甓甕甗甔甖瓩甘甚甜甞　生甡產甥甦　用甪甫甬甯　田由甲申男甸甽甾畀畋界畎畏町畊甿
畇畔畚畛畜畝留畟畢畤略畦番畫畬畯異畮畷畹畽當畸畿疆疇疊　疋疎疏疐疑　疒疔疞疕疚疝
疢疣疤疥疫疧疲疳疴疵疸疹疼疽疾疿病症痂痊痌痍痒痔痕痗痘痛痞痣痡痢痯痰痳痴痺痼痾痿
瘀瘁瘂瘇瘉瘋瘍瘏瘝瘐瘓瘕瘖瘞瘟瘠瘡瘢瘤瘥瘦瘧瘬瘨瘰瘳瘴瘵瘻瘼療癃癆癇癉癖瘺癑癘癙
癜癤癡癢癥癏癭癧癩癬癮癯癰癱癲疙癶癸登發　白百皂的皆皇皈皐皎皓皖皙皜皚皤皥皦皭皪
皫　皮皴皷皸皺皽　皿盂盃盅盆盈益盌盍盎盒盔盛盜盝盞盟葢盡監盤盥盧盦盭盩盪盬　目盲
直相盼盾省眄眇眈眉眊看盻盰盱眚眛真眠眢眥眦眩眙眯眵眴眶眷眸眺眼眾着眹睨睇睆睊睍睚
睛睜睞睪睡睢督睦睫睠睟睥睹睿瞀睘睯瞋瞍瞎瞑瞞瞠瞪瞥瞧瞬瞳瞯瞭瞰瞶瞻瞽瞿矇矍矓矗矙
瞢矚眭矛矜矞　矢矣知矧矩短矮矰矯矱　石矴矼砆矻砂砉砌砍砑砒砭砢砣砥斫砦破砲砠砧砮
砰硃硏硎硜硝硤硨硫硬硭硯确碆碌碎硼碗碁碇碔碑碓硾碡碪碞碭碟碣碧碩碬碯碰確碼碾磁磅
磊磇磋磐磓磔磕磉磑磛磟磚磧磨磬磯磲磺磽礁磷磻礎磈礙礬礧磴礮礦礪礫礱礴碱示礽社祀祁
祅祇祈祉礿祕祊祏祐祓祔祖祗祚祛祜祝神祟祠祫祲祥祧票祭禆祼祺祿禀禁禋禍禎福禘禊禔禖
禕禡禝禦禠禫禧禪禨禮禰禱禳禴　禸禹禺离禽　禾禿秀私秈秉秆秋种科秕秒秔秘秪租秠𥞊秤
秦秧秩秫秭秬秷秸移稀稂税稈程稌稍稊稔稗稙稚稛稜稟稠稭稹種稱稷稻稼稽稿穀穄穆穉穋穌
積穎穗穜穡穟穢穠穨穩穫穭穰　穴穵究穸穹突空穽穿窀窄窅窆窈窋窊窒窕窖窞窗窘窟窠窨窩
窪窬窮窰窳窵窶窸窣窺窾竂竁竄竅竇竈竊　立竑站竚竝竟章竣童竦竪竭端競　竹竺竽竿笄笈
笊笏笑笙笛笞笤笠笥符笨笋笪笫第笮笆笎笱笳筅筆筇等筊筋筌筍筎筏筐筑筒筓答策筠筤筥筦
筧筩筮筲筴筵筯筱箋箎箂箍箇箔箕算箛箝箠管箏箐箒箑箘箜箊箬箭箯箱箴箸箾節篁範篆篇築
篋篘篔篙篚篝篠篡篤簑篧篨篩篦篪篲篳篺篴篷簀簆簇簋簍簌簏篌篾簃簚簜簟簞簠簡簣簥簦簧
簨簪簫簷簸簵簻簽簾簿簴籃籊籌籍籄籐籔籓籀籙籚籛籜籟籠籤籥籨籧籩籫籮籬籯籲篰米粃籹
粉粒粕粗粘粟粢粤粥粦粧粱粲粹粳粺粼精糈糊糉糕糇糖糗糜糝糞糟糠糓糙糧糦糯糲糴糳糵糶
糎糸系糾紀紂約紅紆紇紈紉紊紋紵紖紏紝紞紽納紐紓純紗紘紙級紛紜素紡索紫紩紬紮累細紲
紳紹紺紼紾紿絀終絃組絆紱絅絏結絶絛絜絝絞絡絢給絨絪絮絰統絲絳絖絹絺絿綁綈綉綆綌綍
綏綑經綃綜綠綢綦綫綬維綮綰網綱綳綴綵綸綹綺綻綽緅緌緎綾緇緊緋綣綯緒緘緝綿緞締緣緤
緦緵編緩緬緯練緻縕緗緙緡緥緲縏緹縈縉縊縋縐縗縛縝縟縣縑繁縞縠縢縫縱縲縳縵縶縷縹縻
總績繄繅繆繇縭縰縴繦織繕繙繚繐繞繢繡繒繩繪繫繭繮繯繳繹辮繻繼纁纂繽繾纆纇纈纘續纍
纖纏纊纑纓纔纛纚纜縧缶缸缺缾罀罃罁罄罅罇罋罌罍罏罐罆网罔罕罘罛罝罟罡罣罥罩罪罭置
罰罨署罳罫罶罵罷罹羃罽罿羅羆羇羈　羊羌美羑羔羖羜羚羝羞羢羣羨義羯羲羵羶羸羹羼羽翀
翁翅翊翌翎習翔翕翛翟翠翡翣翥翦翩翫翬翮翯翰翳翹翱翻翼翽翾翿耀　老考耄者耆耈耋　而
耍耎耐耑　耒耔耕耗耘耙耜耝耞耡耤耦耨耯耰　耳耶耻耽耿聃聆聊聒聖聘聚聞聯聰聲聳聵聶
職聽聾　聿肄肅肆肇　　肉肋肌肓肖肘肚肛肝股肢肥肧肩肫肯肱育肴肸肺胃胄背胗胔胍胎胏
胖胙胚胛胝胞胟胠胭胯胡胥胸胼能胾脂脃脅脇胱脈脊脚脘脛脞脤脣脧脩脥脱脬脯脹脾腆腊腋
腎腐腑腓腔腕腥腦腴腫腮腯腰腱腸腹腠腿膀膂膋膏　腳膈膊膕膚膛膜膝膠膩膰膳膺膴膽膻膾
膿臀臂臄臆臉臊臍臘臙臑臚臝臟臠胤臣臥臧臨　自臬臭臯臲　至致臶臺臻　臼臾舁舀舂舃舅
與興舉舊舋　舌舍舐舒舘舖舛舜舞舝　舟舠舡航般舫舩舷舵舶船舸舲舳舴艇艋艄艖艗艎艘艙
艤艟艨艭艦艫　艮良艱　色艴艷蓢艸艽艾芃芄芊芋芍芎𦬊芒芙芝芟芡芣芤芧芨芥芩芪芫芬芭
芮芯芰花芳芷芸芹芻芼芽苐芾苑茆苒苓苔苕苗苙苛苜苞苟苣苡若苦苧苫英苴苹苻苽苾茀茁茂
范茄茈茅茇苢茉茗荔茜茢茦茨茫茭茯茱茲茴茵茶茷茸茹荀荃萄荊荸荇草荍荏荐荑荒茝荄莛荳
荷荻荼荽莅莊莎莒莓莖莘莞莠莢莧莆莨莩莪莫菟莉莽菀菁菅菇菉菊菑菓菖菔菘菠菜菩堇華菰
菱菲菴菶菹菼菽萁萃萆萊萋萌萍萎萑菡菌萩萐萇萼萬萱萵萸萹落葆葉葍著葘葚葛葡董葦葩葫
葬葭葯葱葳葵葷葸葺葽蒂葑葹蒐葊蒔蒙蒜蒡蒞蒟蒨蒭蒲蒸蒹蒺蒼蒿蓀蓁蓂蓄蓆蓉蓊蓋蓌蓍　
蓑蔀蓐蓓蓞蔌蒯蒱蓧蓫蓬蓮蓰蒓蓴蔻蓺薌蓼蔆蔇蓿蔂蔑蔒蔓蔕蔗蔚蔞蔟蔡蔣蔭蔴蔥蔦蔔蓽蔽
蔬蕺蔾蕃蕉蕊蕎蕕蕖蕘蕙蕝蕞蕡蕢蕨蕩蕪蕭薀薯蕆蕈蕳蕤薁蕷蕸蕾薐薢薄薅薇薈薉薊薑薔薖
薙薛孽薜薦薨薩薪薤蘖薏薰薳薹薺薽薿藄藇藉藎藏藐藍藁藕蔿藚藜藝藟藤藩藥藪藷藹藺蘈藻
藾藿蘄蘅蘆蘇藴蘂虁蘋蘀蘚蘞蘢蘩蘭蘨虀蘧蘸蘿蘼虉虆蘑虍虎虐虓虔處虛虜虞號虡虢虥虣虧
虩　虫虱虯虹虺蚓蚔𧉕蚊蚋蚌蚣蚤蚧蚩蚪蚨蚯蚰蚱蚳蚶蚒蛄蛀蛆蛇蛉蛑蛋蛙蛛蛟蛣蛤蛩蛺蛭
蛾蜹蜂蜃蜇蜈蜋蜓蛸蛹蜕蜀蜉蜍蜊蜎蜘蜚蜜蜡蜣蜩蜥蜺蝃蜴蜞蝀螂蜢蜮蝎蝓蝕蝗蝘蝙蝝蝟蝠
蝏蝥蝦蝮蝱蝶蜷蟮蜻蝌蝨蝡蝣蝤蝴蝸融螓螞螘螟螢螣螥螃螄螫螱螺螻螽螿蟄蟊螬螭螮螯螳蟀
蟆蟈蟋蟣蟪蟒蟚蟠蟬蟲蟭蟹蟻蟾蟳蟶蠃蟿蠁蠅蠆蠍蠕蠖蠛蠜蠟蠡蠢蠣蠨蠹蠱蠲蠶蠻虬血　衁
衄衅衂衆衇衊　行衍衎術衒衕衖街衙衚衝衞衡衢衜衣表衫衰衲衷衺衵衽衾衿袁袈袋袍袒袖袗
袜袚袞袠袤袪被衭袴袵袷袱裁裂裊裎裀裏裒裔裕裘裙補裝裟褎裨裯裰裱裳裴裸裼裹製裾複褊
褌褉褂褪褐褓褘褙褡褚褥褧褫褰褲褦褵褶褻襃襄襋襁𧝞襖襚襌襜襞襛襝襠襟襦襪襏襤褸襫襭
襯襴襲襼襶裌襾西要覃覆覇覈覊　見規覓視覘覜覡覦覩親覬覯覲覷𧢈覺覽覿覥觀覼　角觔觖
觚觝觕解觥觩觫觭觱觳觴觸觶觼觿　言訂訃訇計訊討訐訓訕訖託記訌訏訑訒訛訝訟訣訥訪許
設訩訢訴訶診証註訾詁詆詈詋詎詐詒詔評詖詘詛詞詠詡詢詣詤試詩詫詬詭詮詰話該詳詼詿誆
誄誅誇詵詹誌認誐誑誓誕誘誚語誠誡誣誤誥誦誨説誰課誶誹誼誾調諂諄談諉請諍諏諒諑論諗
諐諛諝諞諟諠諤諦諧諫諭諮諱諳諷諸諺諵諼諾謀謁謂諜諡諴諶謄謅謆謇謌謊謎謐謔謗謙謚講
謝謟謡謏謖謦謨謫謬謳謹謾譁謿證譌譎譏譒譔譖識譙譚譍譜警譟譫譬譯議譴護譸譽讀譾讁變
讌讎讋讒讖讓讙讚讛讜讞讟誯谷谿豁豄　豆豈豋豌豉豇豎豐豒豔豏豕豚豝象豢豨豪豫豬豭豳
豵　豸豹豺貂貆貅貉貊貌貍貓貔貛　貝貞負財貢貤貧貨貪販貫責貯貲貳貴貶貸買貺費貼貽貿
賀賁貰賂賃賄賅資賈賊賉賑賒賓賕賙賚賜賝賞賫賠賡賢賣賤賦質賬賟賭賴賵賮賺賻購賽賾賸
贄贅贈贊贇贍贏贐贓贔贖贑贗贛贉赤赦赧赫赭赬　走赳赴赶起趁趄超越趕趙趣趦趨趯　足趵
趾跁趺趹跂跋跅跌跎跏跑跕跖跚跛距跗跫跟跡跣跨跪跬路跱跳跽踉踊跼踏踐踔踖踝踞踢踣踧
踘踡踟踦踰踴踵踶蹆踽蹁蹂蹄踱蹀蹐蹇蹈蹉蹊躍蹌蹕蹔蹙蹟蹣蹤蹜蹝蹠蹯蹲蹴蹶蹺蹡蹢蹬蹭
蹰躁躄躅躇躉躊躋蹋躐躑躒躓躔躚躡躩躪蹷蹚身躬躭躱軀躶軃躺車軋軌軍軏軒軔軛軟軨軫軸
軹軷軼軺軾較輅輈載輀輇輊輒輓輔輕輗輙輛輜輝輟輦輩輪輞輠輥輧輯輳輸輹輻輭輮輴輶輾輿
轂轄轅轀轆轇轕轉轍轎轏轒轖轘轞轟轡轢轤軕辛辜辟辠辣辥辦辨辭辯　辰辱農　辵迂迄迅迋
迍迎近迓返迕迢迤迥迦迨迪迫迭迮述迴迷迸迹追迺退送适逃逅逆逋逌逍透逐逑途逕逖逗這通
逛逝逞速造逡逢連逭逮週進逵逶逸逷逼遇遁遂遄逾遊運遍過遏遐遑遒道達違遘遥遛遜遞遠遡
遣遢遝遨適遭遮遯遲遴遵遶遷選遹遺遻遼遽避邀邁邂還邅邇邃邈邊邏邐迻邑邛邗邙邕邢　那
邡邦邨邪邠邯邱邲邴邳邵邶邸邰邽郁郅郇郊邾郃郉郄郕郛郎郡郢郤郙郜郟部郭郴郵郯都郿鄂
鄒鄄鄔鄉鄗鄖鄙鄘鄢鄞鄠鄜鄧鄫鄭鄰鄱鄴鄶鄲鄹鄿鄺酇酃酆酈郝酉酊酋酌配酎酒酖酗酢酥酣
酤酡酩酪酬酲酵酷酸酴酹酺醃醅醆醇醉醊醋醍醐醒醓醜醞醡醢醩醪醫醬醮醯醴醲醵醺醽醁醼
釀釁釂釄醱釆采釋釉里重野量釐鋅金釗釘釜針釣釧釬釦釭釵鈇鈀鈍鈎鈐鈒鈔鈕鈞鈴鈸鈺鉁鈿
鉅鉉鉏鉗鉛鉞鉢鉤鉋鉶鉸鉦銀銃銅銎銍銑銓銖銘銛銜銚鋭銶銷銹銼鋈鋌鋏鋒鋟鋘鋤鋩鋪鋙銲
鋸鋼錄錐錕錘錙錚錠錢錦錨錫錮錯錞錡鍊鍋鍛鍪鍫鍬鍵鍼鍾鍇鍍鍔鍠鍤鍥鍭鍰鎔鎉鎖鎗鎚鎛
鎞鎡鎌鎧鎬鎰鎮鎊鏃鏈鏑鏖鏗鏘鏜鏡鏝鏢鏞鏤鏟鏐鏦鏨鐃鏵鐓鏹鐘鐙鐫鐮鐲鐵鐶鐸鐩鐺鐻鑄
鑊鑌鑑鑒鑤鑕鑛鑠鑢鑣鑪鑰鑯鑲鑵鑷鑱鑼鑽鑾鑿錳長　門閂閃閆閉閈開閎閏閑閒間閔閘閟閡
閤閣閥閨閩閫閬閭閱閶閹閻閼閽閾闃闇闈闉闊闋闌闍闐　闓闔闕闖闒關闚闠闡闞闢闤闥闆阜
阝阞阡阤阨阬阮阯阱防阪阻阼阿陀陂附陋限陌降陔陘陛陜陞陟陡院陣除陪陬陰陲陳陴陵陶陷
陸陼陽陻隍隄隅隆隈隉隊隋階隔隕隖隗隘隙際障隣隤隧隩險隮隰隱隳隴隨隶隸　隹隻隼雀雁
雄雅集雇雉雋雌雍雎雊雒雕嶲雖雘雙雛雜雝雞離難　雨雩雪雯雰雱雲零雷雹電需𩂯霅霄霈霉
霆震霍霎霏霑霓霖霜霞霢霤霧霰霪霱露霶霸霹霮霽靀霾靄靂靆靈靉霨青靖靚靛靜　非靠靡　
面靦靧靨　革靳靴鞅靶靷靸鞀鞉鞍鞏鞋鞗鞘鞙鞞鞚鞟鞠鞦鞫鞬鞭鞮鞱鞶鞸鞹鞾韁韃韆韀　韋
韍韓韌韎韐韒韔韝韘韙韜韞韈韠　韭韮韱　音韶韻響韺頀　頁頂頃項頇順須頌頏預頑頒頷頓
頊頍頎頖頗領頞頡頤　頲頦頫頭頮頰頴頳頸頽頻顆顇顋題額顏頿顓願顙顛類顜顢顥顦顧顫顯
顰顱顴　風颭颯颶颸颿颺颻颼飄飆飀颽　飛　食飡飢飣飦飧飩飪飫飭飲飯飴飼飽飾飶餂餃餅
餈餉飬餌餐餖餗餒餓餔餕餘餛餚餡餞餤餟餧館餬餮餱餲餳餹餼餽饁饅饈饉饋饌饎饐饑饒饔饕
饗饜饟饞　首馘馗　香馥馨馝馡馣　馬馭馮馳馴馱馹駁駃駐駑駒駕駘駙駛駋駜駝駟駪駉騈駬
駭駮駱駵駰駸駿騌騁騅騂騃隲騑騎騋騏騖騄騙驄騠騣騤騧騫騰騶騵騸騷騮騾驀驁驂驃驅驈騻
驊驔驍驖驕驌驗驒驚驘驙驛驟驢驤驥驩驪駗骨骩骭骯骱骰骷骸骼骽髀骾髏髆髑髒體髖髓　高
　髟髠髢髣髦髧髫髭髮髥髳髴髻髹鬆鬈鬅鬋鬍鬐鬒鬑鬘鬔鬙鬚鬟鬣鬢鬎鬥鬨鬧鬩鬭鬮　鬯鬱
　鬲鬴鬵鬷鬻　鬼魁魂魃魄魊魅魏魐魀魈魍魎魑魔𩴾魘　魚魨魯鮀魴鮎鮒鮐鮓鮞鮪鮆鮑鯗鮮
鮫鯀鯉鯁鯊鯖鯢鯧鯫鯤鯨鯽鰂鯿鰈鰍鰌鰕鰓鰥鰜鰣鰭鰲鰷鰻鱄鱉鱔鱘鱟鱠鱣鱗鱎鱖鱨鱷鱸魺
鳥鳦鳩鳧鳲鳳鳴鳶鴄鴟鴆鴇鴈鴉鴃鳸鴛鴞鴣鴦鴨鴒鴝鴻鴿鴽鵀鵂鵜鵝鵑鵠鵓鵡鵒鵪鵰鵲鶉鵩
鵬鵾鶃鶖鶘鶚鶩鶯鶱鶴鶵鶺鶿鶊鷇鶬鶹鶻鶼鷁鷂鷄鷃鷗鷓鷕鷖鷙鷥鷩鷲鷹鷺鷦鷯鷴鷸鸇鸑鷽
鸕鸚鸞鷟鸛鸝鴹鹵鹹鹼鹽鹺　鹿麂塵麀麃麇麈麋麌麐麑麒麓麕麗麚麛麝麞麟麢麤　麥麫麯麰
麴　麻麽麾黁黃黈黌　黍黏黎黐　黑黔默黛黜點黝黠黥黧黨黯黴黮黶黷　黹黻黼　黽黿鼃鼂
鼇鼈鼉　鼎鼐鼏鼒　鼓鼕鼗鼖鼙鼛鼚　鼠鼢鼫鼬鼯鼹鼷　鼻鼽鼾齁齅　齊齋齎齏　齒齔齕齗
齟齡齠齦齧齩齬齪齮齲齶齷齣龍龎龔龕　龜　龠龢龥　　　　　　　　　　　　　　　　　
　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　
　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　
　万丌丘　　　　　　　丳与　　　　　　　　体僣　　　么　　　　亄　　　　　　　　
　亍亓亘亝偌偭働儍佣侢仈伾伀伃伈傢佂佇佉佌佫佴佹佼侀侁侐侘侚侜俁俜俴倔倞倢倮偝偩
偬偯偷傁傺儡僤僬儦儩儺俌俥偘𫣲僼党兙兛兝兞冔　　　　　　　　　冨冼　　　　　　　
　刓刜剏剌剚剠劘剷　　勑勔勛勡　　匆　　　　　　　　　　　　　卹卼　　　　　　　
吴厖厪　　　叐咼唔吋呎吰咮唶啍喌喨嗀嗁嗈嗊嘌嘍嘓嘮嘸嘽噀噂噭噳𡃱嚄嚆嚌嚎嚕嚦嚭哪
喴唇嘜听嘛噠哢响啡囝囡囥圊圌圛圞垃堍坯堿埕圯圾坱坴垌垗垟埆埌埽堀堄堋堳塥塷墻壒埇
埝埧垕塽堉坿𡋟堎埔㘾壋奜㚟𤳦夼　　　　　　妵姁姶妳姺姽娀娸娬妸婤嫈婼媮婿嫏嫳嫽嫿
嬡姘她婥孃媜娒嫻嫵孓孻寪　　　　　　　　　尀　　　　　　　　屇屄屜屪屫岙峇岬峝崤
岞屴崽岍峪峫峱崆崟崴嶓嶥嶢嶮嶰巇崞嵂岊崮岧帣幞幠幦幨幩　幈　　庈庤𢊈廒廧廍廎廔　
　异　　　　　　　　　弌弎虨　　　　　　　彴彽　悆　　　　　怀怭怲恓恔惔惷惽愃愓
慉　懠懮懰戄您恬憙恵惦戭　　　　　　　　　戹戺　　　挷撑撶𢪘攆扡抿拶挐挱捃揑捘掂
掗掙掤捺揎揕摉揥　揶揵搧搯搰摔摜摦摲摷摻𢵧擖搌攏掮搤搾搿搡撏撦敜敳敹敿敫　　　　
　斚斠　　　　　　　　　　　　　　　　　　旗　　　　　　　昜昬昄旼昊曆昰晅晜晟晢
晾暋暌暓曖　暔晒曄暲昺朌朣　椾杈枱朳椪檨欉机朾杅杙杷杻枬枒枓柺柂柅柣柤　柲柶栔栝
栞栫栭栵桋桬桭梡梩梴棑棜棪棸椌椏椑楀楂楄楎楬楰樠樿橇橤檇檎檑檴橣檿櫌欑欙槼橚燊樳
橒栓櫉櫸柸梘栒檙橌栟　欼歈歊歗歜歁　　　殭歾殈殣毈　　　　　　　毚氝氧氥氦氫𣱢氮
氬毿淳浬浭湟　湋漋泒浤汆氿汋汍汽　沇沕泃泜洏洑洩浧涊涁溨洴淓淠淢淥淵淶淼　渫渮渲
渼湢溴滉滊滏漷潚澐瀅瀌瀳溎洤灥澔焉燨焱煃燏炅烙焄煁煙燉燋焻熿煐𤌚𤉶烱烓熤烳煝熉牏
牐牼犆犇犔犛犫牠　　　犵犺狅狉狘狨狫猆猈猲獀獆獝獢獫獾獼𤢛　　玆　　　　　　　玞
玥玗琱琿璅璊璚璩瓌瓖珛瑢瑄珔琼玶瓗瑂琷琰璉甀甏甒甆　甤甩　　　畈疃　　　　𤺥瘃癌
癳疘痁痐痚痠痤痱痵痻瘈瘌瘭瘯瘶瘸癟癠痧瘄疶癿　　　　　　　　　盚　　　　　　　　
　盵盹眂眅眎眏眕睅睒睙睬睽瞌瞏瞟瞫矔睻　　矟　　　　　　　　　矬矸碚碉砟矽硍𥖁礄
礞砞碍碏碈碻磒磠磡砝碘硐祙禚禜禤　　　　　稑稺穈穧穮秴　　　　窔窌窴窿　　　　　
　竢　　　　　　　　　竾　笰笲笵筘筭筳箄箙篜篟篥𥲻簉簹籝籣籭簰筷篢　　　　粎粍籽
糅籼粞粮粻粽糔糰粿籸緱紃紑紕絓絻綅綎綖綪緜緄線緰緶縚縮繖繘繠縇緓纙縿纕繃缽罎　　
　罦罻罾　　　　　　　羋羭羱　　　　　　　羿羾翃翪　　　　　　耏　　　　　　　　
　聓聝聱　　　　　　　肜　肵胆胺胰胹脄脆脉脖脗脝脡脢脰腂腌腍腒腶膇膘膟膨膷臈臏臐
　臛肪腺膆　　　舿舺艌舨艑艣艥艩艬舢艚𦩀苠荁荅菆茾菸菻萴葄葓蒢蓪蓯蓷蓘蔋蔙蔫薧薸
薾藘藙蘤蘺𦼖莦芘葠茬蘐虒虖　　　　　　　　蚠蚡蛐蛓蛔蜑蜒蜨蜾蜿蝯螉螗螵蟁蟜蟢蠋蠐
蠙蠓蠭蠮蝻蜆蠔蚜　蚵袟衩衮袇袢袲袺袽袿裋裦褒褕褽襥襍襡襢襮襬裡襔褳𧞅　　　　　　
　觜觡觷　　詑　誖　讅訆訧訽詉詧詻詾誃諆諢譈讇讕詨詊讑詷謷譅譆豀　　　　　　　　
　豗豣豶豷　　　　　　　貜　貟賩賛　　　　趡趫趟趲　　踁跴跤踪跦跲踹蹏蹩蹻　躗躞
躘跧趼蹼躧　　　　　　軘軜軝軥轑轗轝軻轊轔　　　　　　　　　逯逄遫邋逴遰　　　　
　邧邿郈郔　郚　郠郪郫郳鄓鄀鄆鄇鄋鄍鄎鄏鄐鄑鄣鄤鄩鄬鄻鄾酅邘鄯郾郗鄈鄚　　　　醝
釅酏醎醑醹醻釃鉌鎤鐄鍏鈹鉀鉑鋂鉼錩鎩鏇鏊鏚錪鐐鐏鐔鐧鑅鑫錁鋆錆鎣錟鎏釙鈁鋕鋐鈊錂
銈閙閧閿　　　　　　　陑陾隃随隵阽𨻧　　　雂雃　　　　　　　　霙霣靁霂　　　　　
　靝　　　　　　　　　靮靺鞃鞌鞛鞨韅靼　　韡韣　　　韹　　　　頄頜𬱃頠頯顗顎顒　
颱　颮　　　　　　　　飜　　　　　　　　　飥養餑餪餫餺餻饘饍𩟝餿　　　馪　　　騉
驫馵駓駔駴駽駾騢騯驦騆　　　　　　　　　　髁　　　　　　　　　髽鬃鬁　　　　　　
　　魋魗　　　　　　　鮚鯈鯔鰉鰋鰒鰱鰾鱏鱐鱓鱧鱭鱮鱯鱻鮭鮿鰵鰐鯛魷鯕　　　　　　
　鳷瞗鴥鵷鵻鷊鷫鸂𪆟鸘鴕鶡　　　　　　　　麩麵麱　　　　　　　黟黰　　　　　　　
　鼪鼴　　　　　　　　　龡銒鉍鈷鉻鈉鈣鉥銻鋁鋝鋃錔鎂鎳鐳鏛鎢鉬錖錏鍚鋰釩鎘銾鈾鍈
鏻鍹鉎鐉鉷鋇鈄侴佰伕俤　乒乓砃砅砵砷砳砸砽硅硔碶碴碳硻磹硋硪巃嶴嵼瑔珺琺瑭璭璦湳
泩洺淌泵澬濚濙瀞灄吔吽咪吱咟吧咖啤坨堌堨堽垻𡊐垸埰壳塝墘垊埗壢煚焴烯熳燡燁𤆬煟燫
𡇥𡆫焊錶釷鈦鉄　　　　侄佬哖塭妬嬿屘崁嵙氖氟氨氰灯畑烊琍碖磘苳萣菎莿蔘萼鯓鰮鰹　
　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　
　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　
　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　
　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　
　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　　
""".replace("\n", "")
